@@ -289,7 +289,7 @@ check_estimate_required_params <- function(the_expr, distr_key) {
       result <- structure(list(shape = this_shape, rate = this_rate))
       return(result)
     }else{
-      stop("Error - distribution is gamma while parameters are not mean and sd")
+      stop("Error - distribution is gamma, but parameters are not mean and sd")
     }
   } else {
     print("For the distributions other than gamma,the code is not equipped to
@@ -478,11 +478,7 @@ form_expression_glm <- function(param_to_be_estimated, indep_var, family,
   }
   if (length(covariates) == 0 | sum(is.na(covariates)) == length(covariates)) {
     # no need to check for interaction
-    fmla <- paste("glm(", param_to_be_estimated, " ~ ", indep_var, ",
-                  family = ", family_def,
-                  ", data = dataset, na.action =", naaction, ")",
-                  sep = ""
-    )
+    fmla <- paste("glm(", param_to_be_estimated, " ~ ", indep_var, ", family = ", family_def, ", data = dataset, na.action =", naaction, ")", sep = "")
     short_fmla <- paste(" ~ ", indep_var, sep = "")
   } else {
     expre <- paste(covariates[1], sep = "")
@@ -496,11 +492,7 @@ form_expression_glm <- function(param_to_be_estimated, indep_var, family,
       }
       i <- i + 1
     }
-    fmla <- paste("glm(", param_to_be_estimated, " ~ ", expre, " + ",
-                  indep_var, ", family = ", family_def,
-                  ", data = dataset, na.action =", naaction, ")",
-                  sep = ""
-    )
+    fmla <- paste("glm(", param_to_be_estimated, " ~ ", expre, " + ", indep_var, ", family = ", family_def, ", data = dataset, na.action = ", naaction, ")", sep = "")
     short_fmla <- paste(" ~ ", expre, " + ", indep_var, sep = "")
   }
   expressions <- list(formula = fmla, short_formula = short_fmla)
@@ -624,7 +616,8 @@ check_link_glm <- function(family, link) {
 #' @param param_to_be_estimated  parameter of interest
 #' @param dataset data set to be provided
 #' @param indep_var the independent variable (column name in data file)
-#' @param covariates list of covariates - calculations to be done before passing
+#' @param covariates list of covariates - calculations to be done before
+#' passing
 #' @param interaction boolean value to indicate interaction in the case
 #' of linear regression, false by default
 #' @return the results of the regression analysis
@@ -714,12 +707,10 @@ do_diagnostic_glm <- function(method = "glm", fit, expression_recreated,
   on.exit(graphics::par(oldpar))
   grDevices::dev.off()
 
-
   name_file_plot <- paste0(method, "_Residuals_", param_to_be_estimated, "_",
                            indep_var, ".pdf", sep = "")
   grDevices::pdf(name_file_plot)
-  plot_diagnostics <- ggplot2::autoplot(fit, toPdf = TRUE,
-                                        file = name_file_plot)
+  plot_diagnostics <- graphics::plot(fit)
   grDevices::dev.off()
 
   results <- list(
@@ -834,7 +825,8 @@ form_expression_lm <- function(param_to_be_estimated, indep_var, covariates,
 #' @param param_to_be_estimated  parameter of interest
 #' @param dataset data set to be provided
 #' @param indep_var the independent variable (column name in data file)
-#' @param covariates list of covariates - calculations to be done before passing
+#' @param covariates list of covariates - calculations to be done before
+#' passing
 #' @param interaction boolean value to indicate interaction in the case of
 #' linear regression, false by default
 #' @return the results of the regression analysis
@@ -1048,7 +1040,8 @@ get_slope_intercept_cross <- function(expression, random_intercept_vars,
       len_ran_eff <- length(random_intercept_vars)
       len_inte_pairs <- length(unlist(intercept_vars_pairs))
       if (len_ran_eff > len_inte_pairs) {
-        mem_checks <- !(random_intercept_vars %in% unlist(intercept_vars_pairs))
+        mem_checks <- !(random_intercept_vars %in%
+                          unlist(intercept_vars_pairs))
         notin_intercept <- random_intercept_vars[mem_checks]
         m <- 1
         for (m in seq_len(length(notin_intercept))) {
@@ -1371,7 +1364,7 @@ get_slope_intercept_nested <- function(expression, random_intercept_vars,
 #' datafile <- system.file("extdata", "data_linear_mixed_model.csv",
 #' package = "packDAMipd")
 #' dt = utils::read.csv(datafile, header = TRUE)
-#' formula <- form_expression_mixed_model("extro",
+#' formula <- form_expression_mixed_model_lme4("extro",
 #'   dataset = dt,
 #'   fix_eff = c("open", "agree", "social"),
 #'   fix_eff_interact_vars = NULL,
@@ -1385,11 +1378,12 @@ get_slope_intercept_nested <- function(expression, random_intercept_vars,
 #' @export
 #' @details
 #' Form the expression for mixed model
-form_expression_mixed_model <- function(param_to_be_estimated, dataset,
+form_expression_mixed_model_lme4 <- function(param_to_be_estimated, dataset,
                                         fix_eff,
                                         fix_eff_interact_vars,
                                         random_intercept_vars,
-nested_intercept_vars_pairs, cross_intercept_vars_pairs,
+                                        nested_intercept_vars_pairs,
+                                        cross_intercept_vars_pairs,
                                         uncorrel_slope_intercept_pairs,
                                         random_slope_intercept_pairs,
                                         family, link) {
@@ -1460,11 +1454,7 @@ nested_intercept_vars_pairs, cross_intercept_vars_pairs,
     all_interact_vars <- ""
     while (i <= length(fix_eff_interact_vars)) {
       if (i == length(fix_eff_interact_vars)) {
-        if (!is.null(random_intercept_vars)) {
-          this <- paste(fix_eff_interact_vars[i], "+ ")
-        } else {
-          this <- paste(fix_eff_interact_vars[i])
-        }
+        this <- paste(fix_eff_interact_vars[i], "+ ")
       } else {
         this <- paste(fix_eff_interact_vars[i], "* ")
       }
